@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'cinder::api' do
   shared_examples 'cinder api' do
     let :pre_condition do
-      "class { '::cinder::keystone::authtoken':
+      "class { 'cinder::keystone::authtoken':
          password => 'foo',
       }"
     end
@@ -30,6 +30,7 @@ describe 'cinder::api' do
         is_expected.to contain_cinder_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/osapi_volume_base_URL').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/osapi_max_limit').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('DEFAULT/os_region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/auth_strategy').with_value('keystone')
         is_expected.to contain_cinder_config('key_manager/backend').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>')
@@ -43,6 +44,17 @@ describe 'cinder::api' do
       end
     end
 
+    context 'with a custom region for nova' do
+      let :params do
+        req_params.merge({'os_region_name' => 'MyRegion'})
+      end
+      it 'should configure the region for nova' do
+        is_expected.to contain_cinder_config('DEFAULT/os_region_name').with(
+          :value => 'MyRegion'
+        )
+      end
+    end
+
     context 'with a customized port' do
       let :params do
         req_params.merge({'osapi_volume_listen_port' => 9999})
@@ -169,9 +181,9 @@ describe 'cinder::api' do
       end
 
       let :pre_condition do
-        "include ::apache
+        "include apache
          class { 'cinder': }
-         class { '::cinder::keystone::authtoken':
+         class { 'cinder::keystone::authtoken':
            password => 'foo',
          }"
       end
@@ -191,9 +203,9 @@ describe 'cinder::api' do
       end
 
       let :pre_condition do
-        "include ::apache
+        "include apache
          class { 'cinder': }
-         class { '::cinder::keystone::authtoken':
+         class { 'cinder::keystone::authtoken':
            password => 'foo',
          }"
       end
